@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Rinci::AddPrereqs;
 
-our $DATE = '2016-08-31'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2016-09-29'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -48,21 +48,15 @@ sub _add_prereq {
 }
 
 sub _add_prereqs_from_func_meta {
-    require Perinci::Sub::Util::PropertyModule;
 
     my ($self, $meta, $cli_info) = @_;
 
     $meta = normalize_function_metadata($meta);
 
-    # from deps, XXX support digging into 'any' and 'all'
-    if (my $deps = $meta->{deps}) {
-        $self->_add_prereq("Perinci::Sub::DepChecker"=>0);
-        for (keys %$deps) {
-            # skip builtin deps supported by Perinci::Sub::DepChecker
-            next if /\A(any|all|none|env|code|prog|pkg|func|exec|
-                         tmp_dir|trash_dir|undo_trash_dir)\z/x;
-            $self->_add_prereq("Perinci::Sub::Dep::$_"=>0);
-        }
+    {
+        require Perinci::Sub::Util::DepModule;
+        my $mods = Perinci::Sub::Util::DepModule::get_required_dep_modules($meta);
+        $self->_add_prereq($_ => $mods->{$_}) for keys %$mods;
     }
 
     {
@@ -94,15 +88,17 @@ sub _add_prereqs_from_func_meta {
             }
 
             # from schema (coerce rule modules, etc) (cli scripts only)
-            my $sch = $arg_spec->{'schema'};
-            if ($sch) {
+            {
+                last unless $cli_info;
+                my $sch = $arg_spec->{'schema'};
+                last unless $sch;
                 state $plc = do {
                     require Data::Sah;
                     Data::Sah->new->get_compiler('perl');
                 };
                 my $cd = $plc->compile(schema => $sch);
                 for my $mod (@{ $cd->{modules} }) {
-                    if ($cli_info && $cli_info->[3]{'func.is_inline'}) {
+                    if ($cli_info->[3]{'func.is_inline'}) {
                         next unless $mod->{phase} eq 'runtime';
                     } else {
                         next unless $mod->{phase} eq 'compile';
@@ -115,6 +111,7 @@ sub _add_prereqs_from_func_meta {
 
     # property modules
     {
+        require Perinci::Sub::Util::PropertyModule;
         my $mods = Perinci::Sub::Util::PropertyModule::get_required_property_modules($meta);
         $self->_add_prereq($_ => 0) for @$mods;
     }
@@ -211,7 +208,7 @@ Dist::Zilla::Plugin::Rinci::AddPrereqs - Add prerequisites from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.11 of Dist::Zilla::Plugin::Rinci::AddPrereqs (from Perl distribution Dist-Zilla-Plugin-Rinci-AddPrereqs), released on 2016-08-31.
+This document describes version 0.12 of Dist::Zilla::Plugin::Rinci::AddPrereqs (from Perl distribution Dist-Zilla-Plugin-Rinci-AddPrereqs), released on 2016-09-29.
 
 =head1 SYNOPSIS
 
